@@ -1,9 +1,10 @@
-"""Assignment helper functions for Selenium testing."""
+﻿"""Assignment helper functions for Selenium testing."""
 
 import random
 import string
 import time
 import inspect
+import datetime
 
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.action_chains import ActionChains
@@ -14,12 +15,10 @@ from selenium.webdriver.support.ui import WebDriverWait
 class Assignment(object):
     """Shortcut functions to add, edit, and delete assignments."""
 
-    # Assignment types
     READING = 'reading'
     HOMEWORK = 'homework'
     EXTERNAL = 'external'
     EVENT = 'event'
-    REVIEW = 'review'
 
     BEFORE_TITLE = 'title'
     BEFORE_DESCRIPTION = 'description'
@@ -88,19 +87,6 @@ class Assignment(object):
                     periods=periods,
                     status=state)
             ),
-            Assignment.REVIEW:
-            (
-                lambda driver, name, description, periods, reading_list, state,
-                problems, url:
-                self.add_new_review(
-                    driver=driver,
-                    title=name,
-                    description=description,
-                    periods=periods,
-                    assessments=problems,
-                    assignment_url=url,
-                    status=state)
-            ),
         }
         self.edit = {
             Assignment.READING:
@@ -150,19 +136,6 @@ class Assignment(object):
                     periods=periods,
                     status=state)
             ),
-            Assignment.REVIEW:
-            (
-                lambda driver, name, description, periods, reading_list, state,
-                problems, url:
-                self.change_review(
-                    driver=driver,
-                    title=name,
-                    description=description,
-                    periods=periods,
-                    assessments=problems,
-                    assignment_url=url,
-                    status=state)
-            ),
         }
         self.remove = {
             Assignment.READING:
@@ -212,19 +185,6 @@ class Assignment(object):
                     periods=periods,
                     status=state)
             ),
-            Assignment.REVIEW:
-            (
-                lambda driver, name, description, periods, reading_list, state,
-                problems, url:
-                self.delete_review(
-                    driver=driver,
-                    title=name,
-                    description=description,
-                    periods=periods,
-                    assessments=problems,
-                    assignment_url=url,
-                    status=state)
-            ),
         }
 
     @classmethod
@@ -235,10 +195,22 @@ class Assignment(object):
 
     @classmethod
     def scroll_to(cls, driver, element):
-        """Execute a scroll to element using javascript."""
+        """Execute a scroll until in view javascript."""
         driver.execute_script('return arguments[0].scrollIntoView();', element)
         driver.execute_script('window.scrollBy(0, -80);')
 
+    @classmethod
+    def send_keys(cls, driver, element, text):
+        """Send data to an element using javascript."""
+        print('Scroll to element')
+        Assignment.scroll_to(driver, element)
+        print('Clear the text box')
+        element.clear()
+        time.sleep(0.5)
+        print('Set text: %s' % text[:61] + '...' if len(text) > 61 else '')
+        for ch in text:
+            element.send_keys(ch)
+
     def open_assignment_menu(self, driver):
         """Open the Add Assignment menu if it is closed."""
         try:
@@ -254,20 +226,63 @@ class Assignment(object):
     def assign_periods(self, driver, periods):
         """Assign open and close dates."""
         # assign the same dates for all periods
+        today = datetime.date.today()
         if 'all' in periods:
             opens_on, closes_on = periods['all']
-            open_xpath = '//div[contains(@class,"-assignment-open-date")]' + \
-                         '//input[@class="datepicker__input"]'
-            close_xpath = '//div[contains(@class,"-assignment-due-date")]' + \
-                          '//input[@class="datepicker__input"]'
-            driver.find_element(By.XPATH, close_xpath).clear()
-            driver.find_element(By.XPATH, close_xpath).send_keys(closes_on)
+            today = datetime.date.today()
+            driver.find_element(
+                By.XPATH, '//div[contains(@class,"-due-date")]' +
+                '//div[contains(@class,"datepicker__input")]'
+            ).click()
+            # get calendar to correct month
+            month = today.month
+            year = today.year
+            while (month != int(closes_on[:2]) or year != int(closes_on[6:])):
+                driver.find_element(
+                    By.XPATH,
+                    '//a[contains(@class,"navigation--next")]'
+                ).click()
+                if month != 12:
+                    month += 1
+                else:
+                    month = 1
+                    year += 1
+            driver.find_element(
+                By.XPATH, '//div[contains(@class,"datepicker__day")' +
+                'and contains(text(),"' + (closes_on[3:5]) + '")]'
+            ).click()
             time.sleep(0.5)
-            driver.find_element(By.CLASS_NAME, 'assign-to-label').click()
-            driver.find_element(By.XPATH, open_xpath).clear()
-            driver.find_element(By.XPATH, open_xpath).send_keys(opens_on)
+            driver.find_element(
+                By.CLASS_NAME,
+                'assign-to-label'
+            ).click()
+            driver.find_element(
+                By.XPATH, '//div[contains(@class,"-open-date")]' +
+                '//div[contains(@class,"datepicker__input")]'
+            ).click()
+            # get calendar to correct month
+            month = today.month
+            year = today.year
+            while (month != int(opens_on[:2]) or year != int(opens_on[6:])):
+                driver.find_element(
+                    By.XPATH,
+                    '//a[contains(@class,"navigation--next")]'
+                ).click()
+                if month != 12:
+                    month += 1
+                else:
+                    month = 1
+                    year += 1
+            driver.find_element(
+                By.XPATH,
+                '//div[contains(@class,"datepicker__day")' +
+                'and contains(text(),"%s")]' % opens_on[3:5]
+            ).click()
             time.sleep(0.5)
-            driver.find_element(By.CLASS_NAME, 'assign-to-label').click()
+            driver.find_element(
+                By.CLASS_NAME,
+                'assign-to-label'
+            ).click()
             return
         # or set the dates for each period: {period: (open, close)}
         count = 0
@@ -283,21 +298,21 @@ class Assignment(object):
                     By.XPATH,
                     '//input[@id="period-toggle-%s"]' % count +
                     '/../following-sibling::div/following-sibling::div' +
-                    '//input[contains(@class,"picker")]'). \
-                    send_keys(closes_on)
+                    '//input[contains(@class,"picker")]'
+                ).send_keys(closes_on)
                 time.sleep(0.5)
                 driver.find_element(By.CLASS_NAME, 'assign-to-label').click()
                 driver.find_element(
                     By.XPATH,
                     '//input[@id="period-toggle-%s"]' % count +
                     '/../following-sibling::div' +
-                    '//input[contains(@class,"picker")]'). \
-                    send_keys(opens_on)
+                    '//input[contains(@class,"picker")]'
+                ).send_keys(opens_on)
                 time.sleep(0.5)
                 driver.find_element(By.CLASS_NAME, 'assign-to-label').click()
 
     def select_status(self, driver, status):
-        """Select the assignment action."""
+        """Select assignment status."""
         if status == self.PUBLISH:
             print('Publishing...')
             element = driver.find_element(By.CLASS_NAME, 'close-x')
@@ -353,7 +368,7 @@ class Assignment(object):
             data_chapter.click()
 
     def select_sections(self, driver, chapters):
-        """Select the sections and chapters for an assignment."""
+        """Select the sections and chapters."""
         for section in chapters:
             if 'ch' in section:  # select the whole chapter
                 print('Adding chapter: ' + section)
@@ -385,8 +400,7 @@ class Assignment(object):
 
     def add_new_reading(self, driver, title, description, periods, readings,
                         status, break_point=None):
-        """
-        Add a new reading assignment.
+        """Add a new reading assignment.
 
         driver:      WebDriver - Selenium WebDriver instance
         title:       string    - assignment title
@@ -448,8 +462,7 @@ class Assignment(object):
         self.select_status(driver, status)
 
     def find_all_questions(self, driver, problems):
-        """Retrieve all available assessments on the page."""
-        # print('Problems: ', problems)
+        """Final all available questions."""
         questions = {}
         section = ''
         wait = WebDriverWait(driver, 5)
@@ -465,7 +478,6 @@ class Assignment(object):
         rows = driver.find_elements(
             By.XPATH,
             '//div[contains(@class,"add-exercise-list")]/*[@class="row"]')
-        # print('FAQ - Row count: %s\n%s' % (len(rows), rows))
         for row in rows:
             children = row.find_elements(By.XPATH, './*')
             if len(children) == 0:
@@ -477,34 +489,30 @@ class Assignment(object):
                         By.XPATH,
                         './/span[@class="chapter-section"]').text
                     questions[section] = []
-                    # print('FAQ - Section tag: %s' % section)
                 except:
                     question = children[0].find_element(
                         By.XPATH,
                         './/span[contains(text(),"@")]').text
                     question = question.split(' ')[1]
                     questions[section].append(question)
-                    # print('FAQ - Exercise tag: %s' % question)
             else:
                 question = children[0].find_element(
                     By.XPATH,
                     './/span[contains(text(),"@")]').text
                 question = question.split(' ')[1]
                 questions[section].append(question)
-                # print('FAQ - Exercise tag: %s' % question)
                 try:
                     question = children[1].find_element(
                         By.XPATH,
                         './/span[contains(text(),"@")]').text
                     question = question.split(' ')[1]
                     questions[section].append(question)
-                    # print('FAQ - Exercise tag: %s' % question)
                 except:
                     pass
         return questions
 
     def get_chapter_list(self, problems, chapter_id):
-        """Retrieve the chapter listing."""
+        """Return available chapters."""
         available = []
         chapter = int(chapter_id[2:])
         for section in problems:
@@ -514,7 +522,7 @@ class Assignment(object):
         return available
 
     def set_tutor_selections(self, driver, problems):
-        """Set the number of Tutor selections for the homework."""
+        """Select the number of Tutor selected problems."""
         tutor_picks = driver.find_element(
             By.XPATH, '//div[@class="tutor-selections"]//h2')
         current = int(tutor_picks.text)
@@ -624,8 +632,7 @@ class Assignment(object):
 
     def add_new_homework(self, driver, title, description, periods, problems,
                          status, break_point=None):
-        """
-        Add a new homework assignment.
+        """Add a new homework assignment.
 
         driver:      WebDriver - Selenium WebDriver instance
         title:       string    - assignment title
@@ -677,16 +684,11 @@ class Assignment(object):
 
     def add_new_external(self, driver, title, description, periods,
                          assignment_url, status):
-        """Add a new external assignment."""
+        """Add an external assignment."""
         raise NotImplementedError(inspect.currentframe().f_code.co_name)
 
     def add_new_event(self, driver, title, description, periods, status):
-        """Add a new event."""
-        raise NotImplementedError(inspect.currentframe().f_code.co_name)
-
-    def add_new_review(self, driver, title, description, periods, assessments,
-                       assignment_url, status):
-        """Add a new test review."""
+        """Add an event."""
         raise NotImplementedError(inspect.currentframe().f_code.co_name)
 
     def change_reading(self, driver, title, description='', periods={},
@@ -708,11 +710,6 @@ class Assignment(object):
         """Edit an event."""
         raise NotImplementedError(inspect.currentframe().f_code.co_name)
 
-    def change_review(self, driver, title, description, periods, assessments,
-                      assignment_url, status):
-        """Edit a test review."""
-        raise NotImplementedError(inspect.currentframe().f_code.co_name)
-
     def delete_reading(self, driver, title, description, periods, readings,
                        status):
         """Delete a reading assignment."""
@@ -731,8 +728,3 @@ class Assignment(object):
     def delete_event(self, driver, title, description, periods, status):
         """Delete an event."""
         raise NotImplementedError(inspect.currentframe().f_code.co_name)
-
-    def delete_review(self, driver, title, description, periods, assessments,
-                      assignment_url, status):
-        """Delete a test review."""
-        raise NotImplementedError(inspect.currentframe().f_code.co_name)
